==> 1.0.6.tar.gz: ios/Classes/SwiftMediametadataretrieverPlugin.swift <==
import Flutter
import UIKit

public class SwiftMediametadataretrieverPlugin: NSObject, FlutterPlugin {
  public static func register(with registrar: FlutterPluginRegistrar) {
    let channel = FlutterMethodChannel(name: "nessmediametadataretriever", binaryMessenger: registrar.messenger())
    let instance = SwiftMediametadataretrieverPlugin()
    registrar.addMethodCallDelegate(instance, channel: channel)
  }

  public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
    //result("iOS " + UIDevice.current.systemVersion)
    guard call.method == "NessMetadataRetriever" else {
          result(FlutterMethodNotImplemented)
          return
    }
    guard let args = call.arguments else {
          return
    }

        if let myArgs = args as? [String: Any],
           let path = myArgs["filePath"] as? String
        {
          getMediaInfo(path: path, result: result)
        }

      private func getMediaInfo(path: String, result: FlutterResult) {
        let url = URL(fileURLWithPath: path)
        let asset = AVURLAsset(url: url)
        let fileManager = FileManager.default
        let isFileExist = fileManager.fileExists(atPath: path)
//
        let metaData = asset.metadata
//
  var title
  var artists
  var album
  var albumArtist
  var duration
  var albumArt

//////////////
    do{
    if let titl = try metaData.first(where: {$0.commonKey == .commonKeyTitle}), let value = titl.value as? String {
        title = value
    }
    if(title == "")	{
  		  title = nil
    }
    } catch {
       title = nil ;
    }
    ////////////////
    do{
    if let alb = try metaData.first(where: {$0.commonKey == .commonKeyAlbumName}), let value = alb.value as? String {
        album = value
    }
    if(album == "")	{
  		  album = nil
    }
    } catch {
    album = nil
    }
    ////////////////
    do{
    if let artist = try metaData.first(where: {$0.commonKey == .commonKeyArtist}), let value = artist.value as? String {
        artists = value
        albumArtist = value
    }
    if(artists == "")	{
  		  artists = nil
  		  albumArtist = nil
    }
    } catch {
    artists = nil
    albumArtist = nil
    }
    ////////////////
    do{
    if let imgson = try metaData.first(where: {$0.commonKey == .commonKeyArtwork}), let value = imgson.value as? Data {
       albumArt = value
    }
    if(albumArt == "")	{
  		  albumArt = nil
    }
    } catch {
    	albumArt = nil;
    }
    //////////////////
        duration = round(CMTimeGetSeconds(asset.duration) * 1000)

        let fps = tracks.first?.nominalFrameRate
        mimeType = mimeTypeForPath(path: path)

        var Data = [String: Any]()
        Data["title"] = mimetype
        Data["artist"] = ""
        Data["album"] = album
        Data["albumArtist"] = durationTime
        Data["duration"] = duration
        Data["albumArt"] = albumArt

        do {
          result(Data)
        } catch let e {
          result(e)
        }
      }
  }
}

==> 1.0.8.tar.gz: ios/Classes/SwiftMediametadataretrieverPlugin.swift <==
import Flutter
import UIKit

public class SwiftMediametadataretrieverPlugin: NSObject, FlutterPlugin {
  public static func register(with registrar: FlutterPluginRegistrar) {
    let channel = FlutterMethodChannel(name: "nessmediametadataretriever", binaryMessenger: registrar.messenger())
    let instance = SwiftMediametadataretrieverPlugin()
    registrar.addMethodCallDelegate(instance, channel: channel)
  }

  public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
    //result("iOS " + UIDevice.current.systemVersion)
    guard call.method == "NessMetadataRetriever" else {
          result(FlutterMethodNotImplemented)
          return
    }
    guard let args = call.arguments else {
          return
    }

        if let myArgs = args as? [String: Any],
           let path = myArgs["filePath"] as? String
        {
          getMediaInfo(path: path, result: result)
        }

      private func getMediaInfo(path: String, result: FlutterResult) {
        let url = URL(fileURLWithPath: path)
        let asset = AVURLAsset(url: url)
        let fileManager = FileManager.default
        let isFileExist = fileManager.fileExists(atPath: path)
//
        let metaData = asset.metadata
//
  var title
  var artist
  var album
  var albumArtist
  var duration
  var albumArt

//////////////
    do{
    if let titl = try metaData.first(where: {$0.commonKey == .commonKeyTitle}), let value = titl.value as? String {
        title = value
    }
    if(title == "")	{
  		  title = nil
    }
    } catch {
       title = nil ;
    }
    ////////////////
    do{
    if let alb = try metaData.first(where: {$0.commonKey == .commonKeyAlbumName}), let value = alb.value as? String {
        album = value
    }
    if(album == "")	{
  		  album = nil
    }
    } catch {
    album = nil
    }
    ////////////////
    do{
    if let artis = try metaData.first(where: {$0.commonKey == .commonKeyArtist}), let value = artis.value as? String {
        artist = value
        albumArtist = value
    }
    if(artist == "")	{
  		  artist = nil
  		  albumArtist = nil
    }
    } catch {
    artist = nil
    albumArtist = nil
    }
    ////////////////
    do{
    if let imgson = try metaData.first(where: {$0.commonKey == .commonKeyArtwork}), let value = imgson.value as? Data {
       albumArt = value
    }
    if(albumArt == "")	{
  		  albumArt = nil
    }
    } catch {
    	albumArt = nil;
    }
    //////////////////
        duration = round(CMTimeGetSeconds(asset.duration) * 1000)

        var Data = [String: Any]()
        Data["title"] = title
        Data["artist"] = artist
        Data["album"] = album
        Data["albumArtist"] = albumArtist
        Data["duration"] = duration
        Data["path"] = path
        Data["albumArt"] = albumArt

        do {
          result(Data)
        } catch let e {
          result(e)
        }
      }
  }
}
